
import { defineStore } from "pinia";
import { ref } from 'vue'

export const usePlayerStateStore = defineStore('playerState', () => {
    const playerState = ref({
        players: [],
        current_player: null,
        is_playing: false,
    })

    function updateIsPlaying() {
        var is_playing = false
        if (playerState.value.current_player == null) {
            is_playing = false
        }
        for (let player of playerState.value.players) {
            if (player.name == playerState.value.current_player && player.playing) {
                is_playing = true
            }
        }
        playerState.value.is_playing = is_playing
    }

    function fixCurrentPlayer() {
        if (playerState.value.current_player == null) {
            return
        }
        let exists = false;
        for (let player of playerState.value.players) {
            if (player.name == playerState.value.current_player) {
                exists = true
            }
        }
        if (!exists) {
            playerState.value.current_player = null
        }
    }

    async function refreshPlayers() {
        const response = await fetch("/api/player/list");
        playerState.value.players = await response.json();
        if (playerState.value.current_player == null && playerState.value.players.length > 0) {
            playerState.value.current_player = playerState.value.players[0].name
        }
        fixCurrentPlayer()
        updateIsPlaying()
    }

    function setCurrentPlayer(player) {
        playerState.value.current_player = player
        refreshPlayers()
    }

    function getCurrentPlayer() {
        if (playerState.value.current_player == null) {
            return null
        }
        for (let player of playerState.value.players) {
            if (player.name == playerState.value.current_player) {
                return player
            }
        }
    }

    return { playerState, refreshPlayers, setCurrentPlayer, getCurrentPlayer }
});